@@ -44,6 +44,9 @@ type IOStreams struct {
 	progressIndicator        *spinner.Spinner
 	progressIndicatorMu      sync.Mutex
 
+	alternateScreenBufferEnabled bool
+	alternateScreenBufferActive  bool
+
 	stdinTTYOverride  bool
 	stdinIsTTY        bool
 	stdoutTTYOverride bool
@@ -278,6 +281,34 @@ func (s *IOStreams) StopProgressIndicator() {
 	s.progressIndicator = nil
 }
 
+func (s *IOStreams) StartAlternateScreenBuffer() {
+	if s.alternateScreenBufferEnabled {
+		if _, err := fmt.Fprint(s.Out, "\x1b[?1049h"); err == nil {
+			s.alternateScreenBufferActive = true
+		}
+	}
+}
+
+func (s *IOStreams) StopAlternateScreenBuffer() {
+	if s.alternateScreenBufferActive {
+		fmt.Fprint(s.Out, "\x1b[?1049l")
+		s.alternateScreenBufferActive = false
+	}
+}
+
+func (s *IOStreams) SetAlternateScreenBufferEnabled(enabled bool) {
+	s.alternateScreenBufferEnabled = enabled
+}
+
+func (s *IOStreams) RefreshScreen() {
+	if s.stdoutIsTTY {
+		// Move cursor to 0,0
+		fmt.Fprint(s.Out, "\x1b[0;0H")
+		// Clear from cursor to bottom of screen
+		fmt.Fprint(s.Out, "\x1b[J")
+	}
+}
+
 // TerminalWidth returns the width of the terminal that stdout is attached to.
 // TODO: investigate whether ProcessTerminalWidth could replace all this.
 func (s *IOStreams) TerminalWidth() int {
@@ -373,10 +404,10 @@ func System() *IOStreams {
 	stdoutIsTTY := isTerminal(os.Stdout)
 	stderrIsTTY := isTerminal(os.Stderr)
 
-	assumeTrueColor := false
+	isVirtualTerminal := false
 	if stdoutIsTTY {
 		if err := enableVirtualTerminalProcessing(os.Stdout); err == nil {
-			assumeTrueColor = true
+			isVirtualTerminal = true
 		}
 	}
 
@@ -386,8 +417,8 @@ func System() *IOStreams {
 		Out:          colorable.NewColorable(os.Stdout),
 		ErrOut:       colorable.NewColorable(os.Stderr),
 		colorEnabled: EnvColorForced() || (!EnvColorDisabled() && stdoutIsTTY),
-		is256enabled: assumeTrueColor || Is256ColorSupported(),
-		hasTrueColor: assumeTrueColor || IsTrueColorSupported(),
+		is256enabled: isVirtualTerminal || Is256ColorSupported(),
+		hasTrueColor: isVirtualTerminal || IsTrueColorSupported(),
 		pagerCommand: os.Getenv("PAGER"),
 		ttySize:      ttySize,
 	}
@@ -396,6 +427,10 @@ func System() *IOStreams {
 		io.progressIndicatorEnabled = true
 	}
 
+	if stdoutIsTTY && isVirtualTerminal {
+		io.alternateScreenBufferEnabled = true
+	}
+
 	// prevent duplicate isTerminal queries now that we know the answer
 	io.SetStdoutTTY(stdoutIsTTY)
 	io.SetStderrTTY(stderrIsTTY)
